@@ -19,12 +19,14 @@ use hmac::Hmac;
 use log::{debug, info, trace};
 use rand::rngs::{OsRng, StdRng};
 use rand_core::SeedableRng;
-use sha3::Sha3_256;
-use sn_client::{client::Client, Error as ClientError, ErrorMessage::NoSuchEntry};
-use sn_data_types::{
+use safe_network::client::{
+    client_api::Client, Error as ClientError, ErrorMessage::NoSuchEntry, DEFAULT_QUERY_TIMEOUT,
+};
+use safe_network::types::{
     Keypair, MapAction, MapAddress, MapEntryActions, MapPermissionSet, MapSeqEntryActions,
     MapValue, Token,
 };
+use sha3::Sha3_256;
 use std::{
     collections::{BTreeMap, HashSet},
     net::SocketAddr,
@@ -189,6 +191,7 @@ impl SafeAuthenticator {
             Some(keypair),
             self.config_path.as_deref(),
             self.bootstrap_contacts.clone(),
+            DEFAULT_QUERY_TIMEOUT,
         )
         .await?;
         trace!("Client instantiated properly!");
@@ -293,6 +296,7 @@ impl SafeAuthenticator {
             Some(keypair),
             self.config_path.as_deref(),
             self.bootstrap_contacts.clone(),
+            DEFAULT_QUERY_TIMEOUT,
         )
         .await?;
         trace!("Client instantiated properly!");
@@ -455,6 +459,7 @@ impl SafeAuthenticator {
                         Some(keypair.clone()),
                         self.config_path.as_deref(),
                         self.bootstrap_contacts.clone(),
+                        DEFAULT_QUERY_TIMEOUT,
                     )
                     .await?;
                     tmp_client
@@ -534,7 +539,7 @@ mod tests {
     use super::*;
     use anyhow::{Context, Result};
     use proptest::prelude::*;
-    use sn_data_types::PublicKey;
+    use safe_network::types::PublicKey;
 
     #[test]
     fn get_deterministic_pk_from_known_seed() -> Result<()> {
